==> org.eclipse.recommenders.jayes.source_2.1.11.v20141028-1429.jar: org/eclipse/recommenders/jayes/inference/RejectionSampling.java <==
/**
 * Copyright (c) 2011 Michael Kutschke.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Michael Kutschke - initial API and implementation.
 */
package org.eclipse.recommenders.jayes.inference;

import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.recommenders.jayes.BayesNet;
import org.eclipse.recommenders.jayes.BayesNode;
import org.eclipse.recommenders.jayes.sampling.BasicSampler;
import org.eclipse.recommenders.jayes.util.MathUtils;

@SuppressWarnings("deprecation")
public class RejectionSampling extends AbstractInferer {

    private int sampleCount = 200;
    private final BasicSampler sampler = new BasicSampler();

    @Override
    public void setNetwork(BayesNet bn) {
        super.setNetwork(bn);
        sampler.setNetwork(bn);
    }

    @Override
    protected void updateBeliefs() {
        for (int i = 0; i < sampleCount; i++) {
            Map<BayesNode, String> sample = sampler.sample();
            boolean isConsistentWithEvidence = isConsistenWithEvidence(sample);
            if (!isConsistentWithEvidence) {
                i--;
                continue;
            }
            for (Entry<BayesNode, String> e : sample.entrySet()) {
                BayesNode n = e.getKey();
                beliefs[n.getId()][n.getOutcomeIndex(e.getValue())]++;
            }
        }

        normalizeBeliefs();
    }

    private void normalizeBeliefs() {
        for (int i = 0; i < beliefs.length; i++) {
            beliefs[i] = MathUtils.normalize(beliefs[i]);
        }
    }

    private boolean isConsistenWithEvidence(Map<BayesNode, String> sample) {
        for (Entry<BayesNode, String> e : evidence.entrySet()) {
            boolean sampleMatchesEvidence = e.getValue().equals(sample.get(e.getKey()));
            if (!sampleMatchesEvidence) {
                return false;
            }
        }
        return true;
    }

    public void setSampleCount(int sampleCount) {
        this.sampleCount = sampleCount;
    }

    public void seed(long seed) {
        sampler.seed(seed);
    }
}

==> org.eclipse.recommenders.jayes.source_2.5.1.v20171220-1141.jar: org/eclipse/recommenders/jayes/inference/RejectionSampling.java <==
/**
 * Copyright (c) 2011 Michael Kutschke.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Michael Kutschke - initial API and implementation.
 */
package org.eclipse.recommenders.jayes.inference;

import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.recommenders.jayes.BayesNet;
import org.eclipse.recommenders.jayes.BayesNode;
import org.eclipse.recommenders.jayes.sampling.BasicSampler;
import org.eclipse.recommenders.jayes.util.MathUtils;

@SuppressWarnings("deprecation")
public class RejectionSampling extends AbstractInferer {

    private static final int DEFAULT_SAMPLE_COUNT = 200;

    private int sampleCount = DEFAULT_SAMPLE_COUNT;
    private final BasicSampler sampler = new BasicSampler();

    @Override
    public void setNetwork(BayesNet bn) {
        super.setNetwork(bn);
        sampler.setNetwork(bn);
    }

    @Override
    protected void updateBeliefs() {
        for (int i = 0; i < sampleCount; i++) {
            Map<BayesNode, String> sample = sampler.sample();
            boolean isConsistentWithEvidence = isConsistenWithEvidence(sample);
            if (!isConsistentWithEvidence) {
                i--;
                continue;
            }
            for (Entry<BayesNode, String> e : sample.entrySet()) {
                BayesNode n = e.getKey();
                beliefs[n.getId()][n.getOutcomeIndex(e.getValue())]++;
            }
        }

        normalizeBeliefs();
    }

    private void normalizeBeliefs() {
        for (int i = 0; i < beliefs.length; i++) {
            beliefs[i] = MathUtils.normalize(beliefs[i]);
        }
    }

    private boolean isConsistenWithEvidence(Map<BayesNode, String> sample) {
        for (Entry<BayesNode, String> e : evidence.entrySet()) {
            boolean sampleMatchesEvidence = e.getValue().equals(sample.get(e.getKey()));
            if (!sampleMatchesEvidence) {
                return false;
            }
        }
        return true;
    }

    public void setSampleCount(int sampleCount) {
        this.sampleCount = sampleCount;
    }

    public void seed(long seed) {
        sampler.seed(seed);
    }
}
